==> download_v2.3.661.zip: download/lang/de.php <==
<?php
######################################################################
# Authors: Franz-Peter Glawar <office@glawar.at>, 2014
#
# This php contains the german language entries
#
#
# (c) www.glawar.at
#
######################################################################
####  History
#---------------------------------------------------------------------
# v2014-11-30 FPG created the script
# v2014-12-02 FPG added new entries for german
######################################################################
####  Variables that should be adapted if necessary
####------------------------------------------------------------------
######################################################################
####  Variables that should not be changed
####------------------------------------------------------------------
######################################################################


$lang = array(
    "listfiles"=> "Dateien",
    "addnewfile" => "Datei hinzufügen",
    "adduser" => "Benutzer hinzufügen",
    "showusers"=> "Benutzer",
    "changepassword" => "Kennwort ändern",
    "logout" => "Abmelden",
    "accountdeactivated"=> "Dein Zugang wurde deaktiviert, bitte kontaktiere Deinen Systemadministrator",
    "userpwdwrong" => "Entweder Kennwort oder Passwort ist falsch, bitte nochmals probieren",
    "username" => "Benutzername",
    "password"=> "Kennwort",
    "login" => "Anmelden",
    "newpassword" => "neues Kennwort",
    "retypepwd"=> "Kennworteingabe wiederholen",
    "filename" => "Dateiname",
    "filedescription" => "Dateibeschreibung",
    "upload"=> "Hochladen",
    "updateuser" => "Aktualisiere Benutzer",
    "lastname" => "Familienname",
    "firstname"=> "Vorname",
    "email" => "E-mail",
    "active" => "Konto aktiv",
    "allowedtoaddfiles"=> "Benutzer darf Dateien hochladen",
    "group" => "Gruppe",
    "nodbaccess"=> "Kein Datenbankzugriff",
    "causedbyselect" => "verursacht durch die Abfrage ",
    "nouserupdate" => "Benutzer konnte nicht aktualisiert werden!",
    "nousercreated"=> "Bennutzer konnte nicht erstellt werden!",
    "passwordminimumlength" => "Das Kennwort benötigt eine minimale Länge von ",
    "errorbindinginput" => "Eingabe Parameter der SQL-Abfrage hatte einen Fehler: ",
    "manageusernotallfieldsfilledout" => "Benutzer konnte weder hinzugefügt noch aktualisiert werden, weil Sie nicht alle benötigten Felder ausgefüllt haben",
    "errorbindingoutput" => "Ausgabe Parameter der SQL-Abfrage hatte einen Fehler: ",
    "nonewfilenofilename" => "Datei konnte nicht hinzugefügt werden: Kein Dateiname wurde angegeben",
    "filenotsaved"=> "Datei konnte nicht gespeichert werden: ",
    "filenotadded" => "Datei konnte nicht hinzugefügt werden",
    "nonewfilenofile" => "Datei konnte nicht hinzugefügt werden: Kein Datei wurde ausgewählt",
    "changepwdfillout"=> "Kennwortänderung: Sie müssen alle benötigten Felder ausfüllen",
    "passwordnotchanged" => "Kennnwort konnte nicht geändert werden",
    "passwordsnotmatch" => "Die angegebenen Kennwörter stimmen nicht überein",
    "created"=> "erstellt",
    "modified" => "geändert",
    "changepermission" => "Änderung der Zugriffsberechtigung",
    "save"=> "Speichern",
    "action" => "Aktion",
    "view" => "Anzeige",
    "filesize" => "Dateigröße",
    "date" => "Datum",
    "logtoscreen" => "Debuganzeige am Schirm",
    "updatedon" => "Aktualisierung durchgeführt",
    "availablefile" => "Verfügbare Dateien",
    "allowedtoaddfiles2"=> "hochladen",
    "active2" => "aktiv",
    "change" => "ändern",
    "user" => "Benutzer",
    "usernameminimumlength" => "Der Benutzername benötigt eine minimale Länge von ",
    "userhaschangedpwd" => "Benutzer hat sein Kennwort geändert",
    "contactSysadmin" => "Ein technisches Problem ist aufgetreten. Bitte kontaktieren Sie Ihren Systemadministrator",
    "noAccessMySQL" => "Kein Zugriff auf die MySQL-Datenbank möglich",
    "notinstalledbasenecessary" => "Sie müssen zuerst den DownloadManager installieren",
    "installationdone" => "Installation durchgeführt",
    "installationof" => "Installation von",
    "providedatabase" => "Sie müssen eine Datenbank mit Benutzername und Kennwort zur Verfügung stellen. Z. B.:",
    "doInstallation" => "Installation durchführen",
    "MySQLDatabase" => "MySQL-Datenbank",
    "creatingdatabasestructure" => "Erzeugung Datenbankstruktur",
    "insertingbasedata" => "Einfügen der Basisdaten",
    "creatingversioncheck" => "Versionstabelle anlegen",
    "creatingconfigentries" => "Konfigurationseinträge erstellen",
    "dbalreadymin" => "Die Datenbank hat bereits die minimal notwendige Version",
    "updatingfromversion1" => "Datenbankupdate wird durchgeführt",
    "passwordforgotten" => "Kennwort vergessen",
    "resetpassword" => "Kennwort zurücksetzen",
    "sendresetpwd" => "Kennwort zurücksetzen via Email",
    "contact" => "Kontakt",
    "sendemail" => "Email senden",
    "emailcontext" => "Ihre Nachricht",
    "emailheader" => "Kontakt",
    "resetPwdEmailHeader" => "Kennwort zurücksetzen",
    "resetPWDEmail" => "Sie haben Ihr Kennwort vergessen und haben die Rücksetzung Ihres Kennworts ausgelöst.",
    "resetPWDEmail2" => "Bitte klicken Sie auf den unten stehenden Link, um Ihr aktuelles Kennwort zurück zu setzen und ein neues zu wählen.",
    "back" => "zurück",
    "myData" => "Meine Daten",
    "changemydata" => "Speichern",
    "changemydatafillout"=> "Ihre Daten: Sie müssen alle notwendigen Felder ausfüllen",
    "showgroups" => "Gruppen",
    "addgroup" => "Gruppe hinzufügen",
    "youremail" => "Ihre Email",
    "updategroup" => "Aktualisiere Gruppe",
    "groupmembers" => "Gruppenmitglied",
    "notenoughpermission" => "Sie besitzen nicht die notwendigen Rechte, um diesen Menüpunkt ausführen zu können.",
    "newupload" => "Neue Datei hochgeladen"
);
?>

==> download_v3.0.681.zip: download/lang/de.php <==
<?php
######################################################################
# Authors: Franz-Peter Glawar <office@glawar.at>, 2014
#
# This php contains the german language entries
#
#
# (c) www.glawar.at
#
######################################################################
####  History
#---------------------------------------------------------------------
# v2014-11-30 FPG created the script
# v2014-12-02 FPG added new entries for german
######################################################################
####  Variables that should be adapted if necessary
####------------------------------------------------------------------
######################################################################
####  Variables that should not be changed
####------------------------------------------------------------------
######################################################################


$lang = array(
    "listfiles"=> "Dateien",
    "addnewfile" => "Datei hinzufügen",
    "adduser" => "Benutzer hinzufügen",
    "showusers"=> "Benutzer",
    "changepassword" => "Kennwort ändern",
    "logout" => "Abmelden",
    "accountdeactivated"=> "Dein Zugang wurde deaktiviert, bitte kontaktiere Deinen Systemadministrator",
    "userpwdwrong" => "Entweder Kennwort oder Passwort ist falsch, bitte nochmals probieren",
    "username" => "Benutzername",
    "password"=> "Kennwort",
    "login" => "Anmelden",
    "newpassword" => "neues Kennwort",
    "retypepwd"=> "Kennworteingabe wiederholen",
    "filename" => "Dateiname",
    "filedescription" => "Dateibeschreibung",
    "upload"=> "Hochladen",
    "updateuser" => "Aktualisiere Benutzer",
    "lastname" => "Familienname",
    "firstname"=> "Vorname",
    "email" => "E-mail",
    "active" => "Konto aktiv",
    "allowedtoaddfiles"=> "Benutzer darf Dateien hochladen",
    "group" => "Gruppe",
    "nodbaccess"=> "Kein Datenbankzugriff",
    "causedbyselect" => "verursacht durch die Abfrage ",
    "nouserupdate" => "Benutzer konnte nicht aktualisiert werden!",
    "nousercreated"=> "Bennutzer konnte nicht erstellt werden!",
    "passwordminimumlength" => "Das Kennwort benötigt eine minimale Länge von ",
    "errorbindinginput" => "Eingabe Parameter der SQL-Abfrage hatte einen Fehler: ",
    "manageusernotallfieldsfilledout" => "Benutzer konnte weder hinzugefügt noch aktualisiert werden, weil Sie nicht alle benötigten Felder ausgefüllt haben",
    "errorbindingoutput" => "Ausgabe Parameter der SQL-Abfrage hatte einen Fehler: ",
    "nonewfilenofilename" => "Datei konnte nicht hinzugefügt werden: Kein Dateiname wurde angegeben",
    "filenotsaved"=> "Datei konnte nicht gespeichert werden: ",
    "filenotadded" => "Datei konnte nicht hinzugefügt werden",
    "nonewfilenofile" => "Datei konnte nicht hinzugefügt werden: Kein Datei wurde ausgewählt",
    "changepwdfillout"=> "Kennwortänderung: Sie müssen alle benötigten Felder ausfüllen",
    "passwordnotchanged" => "Kennnwort konnte nicht geändert werden",
    "passwordsnotmatch" => "Die angegebenen Kennwörter stimmen nicht überein",
    "created"=> "erstellt",
    "modified" => "geändert",
    "changepermission" => "Änderung der Zugriffsberechtigung",
    "save"=> "Speichern",
    "action" => "Aktion",
    "view" => "Anzeige",
    "filesize" => "Dateigröße",
    "date" => "Datum",
    "logtoscreen" => "Debuganzeige am Schirm",
    "updatedon" => "Aktualisierung durchgeführt",
    "availablefile" => "Verfügbare Dateien",
    "allowedtoaddfiles2"=> "hochladen",
    "active2" => "aktiv",
    "change" => "ändern",
    "user" => "Benutzer",
    "usernameminimumlength" => "Der Benutzername benötigt eine minimale Länge von ",
    "userhaschangedpwd" => "Benutzer hat sein Kennwort geändert",
    "contactSysadmin" => "Ein technisches Problem ist aufgetreten. Bitte kontaktieren Sie Ihren Systemadministrator",
    "noAccessMySQL" => "Kein Zugriff auf die MySQL-Datenbank möglich",
    "notinstalledbasenecessary" => "Sie müssen zuerst den DownloadManager installieren",
    "installationdone" => "Installation durchgeführt",
    "installationof" => "Installation von",
    "providedatabase" => "Sie müssen eine Datenbank mit Benutzername und Kennwort zur Verfügung stellen. Z. B.:",
    "doInstallation" => "Installation durchführen",
    "MySQLDatabase" => "MySQL-Datenbank",
    "creatingdatabasestructure" => "Erzeugung Datenbankstruktur",
    "insertingbasedata" => "Einfügen der Basisdaten",
    "creatingversioncheck" => "Versionstabelle anlegen",
    "creatingconfigentries" => "Konfigurationseinträge erstellen",
    "dbalreadymin" => "Die Datenbank hat bereits die minimal notwendige Version",
    "updatingfromversion1" => "Datenbankupdate wird durchgeführt",
    "passwordforgotten" => "Kennwort vergessen",
    "resetpassword" => "Kennwort zurücksetzen",
    "sendresetpwd" => "Kennwort zurücksetzen via Email",
    "contact" => "Kontakt",
    "sendemail" => "Email senden",
    "emailcontext" => "Ihre Nachricht",
    "emailheader" => "Kontakt",
    "resetPwdEmailHeader" => "Kennwort zurücksetzen",
    "resetPWDEmail" => "Sie haben Ihr Kennwort vergessen und haben die Rücksetzung Ihres Kennworts ausgelöst.",
    "resetPWDEmail2" => "Bitte klicken Sie auf den unten stehenden Link, um Ihr aktuelles Kennwort zurück zu setzen und ein neues zu wählen.",
    "back" => "zurück",
    "myData" => "Meine Daten",
    "changemydata" => "Speichern",
    "changemydatafillout"=> "Ihre Daten: Sie müssen alle notwendigen Felder ausfüllen",
    "showgroups" => "Gruppen",
    "addgroup" => "Gruppe hinzufügen",
    "youremail" => "Ihre Email",
    "updategroup" => "Aktualisiere Gruppe",
    "groupmembers" => "Gruppenmitglied",
    "notenoughpermission" => "Sie besitzen nicht die notwendigen Rechte, um diesen Menüpunkt ausführen zu können.",
    "newupload" => "Neue Datei hochgeladen",
    "dbtableprefix" => "Prefix für Datenbanktabellen",
    "nochangeindemo" => "Sie können keine Daten betreffend des Administrators im Demo-Modus ändern",
    "language" => "Sprache",
    "nopermission" => "Sie sind nicht berechtigt, diese Datei herunter zu laden."
);
?>
